==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Додати файли</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="44"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="47"/>
        <location filename="../qmmpfiledialog.ui" line="60"/>
        <location filename="../qmmpfiledialog.ui" line="79"/>
        <location filename="../qmmpfiledialog.ui" line="104"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="57"/>
        <source>List view</source>
        <translation>Перегляд списком</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="76"/>
        <source>Detailed view</source>
        <translation>Деталізований перегляд</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="101"/>
        <source>Close dialog on add</source>
        <translation>Закрити після додавання</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="184"/>
        <source>File name:</source>
        <translation>Ім&apos;я файлу:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="207"/>
        <source>Files of type:</source>
        <translation>Типи файлів:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="233"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="68"/>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>Qmmp File Dialog</source>
        <translation>Діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="77"/>
        <source>About Qmmp File Dialog</source>
        <translation>Про діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Розробники:
Володимир Кузнєцов &lt;vovanec@gmail.com&gt;
Ілля Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="82"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Деякий код скопійовано з бібліотеки Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
        <source>Directories</source>
        <translation>Теки</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 існує.
Ви бажаєте замінити?</translation>
    </message>
</context>
</TS>

==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="13"/>
        <source>Add Files</source>
        <translation>Додати файли</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="37"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="40"/>
        <location filename="../qmmpfiledialog.ui" line="53"/>
        <location filename="../qmmpfiledialog.ui" line="72"/>
        <location filename="../qmmpfiledialog.ui" line="97"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="50"/>
        <source>List view</source>
        <translation>Перегляд списком</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="69"/>
        <source>Detailed view</source>
        <translation>Деталізований перегляд</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="94"/>
        <source>Close dialog on add</source>
        <translation>Закрити після додавання</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>File name:</source>
        <translation>Ім&apos;я файлу:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Files of type:</source>
        <translation>Типи файлів:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="226"/>
        <source>Close</source>
        <translation>Закрити</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="69"/>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Qmmp File Dialog</source>
        <translation>Діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>About Qmmp File Dialog</source>
        <translation>Про діалог файлів Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробники:
Володимир Кузнєцов &lt;vovanec@gmail.com&gt;
Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="83"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Деякий код скопійовано з бібліотеки Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
        <source>Add</source>
        <translation>Додати</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
        <source>Directories</source>
        <translation>Теки</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 існує.
Ви бажаєте замінити?</translation>
    </message>
</context>
</TS>
